@@ -46,9 +46,9 @@ class DTE(ReporteBase,BCRA):
         
         self.filtro = filtro
         
-        try :
-            self.tc = BCRA(cargar_tc=True).tc_udh.copy(deep=True)
-        except:
+        #Intentar cargar el tipo de cambio
+        self.tc = BCRA(cargar_tc=True).tc_udh.copy(deep=True)
+        if self.tc.empty:
             print('No se pudo cargar el Tipo de Cambio según la comunicación 3500 A del BRCRA.')
             self.tc = None
         
@@ -148,13 +148,6 @@ class DTE(ReporteBase,BCRA):
         
         if isinstance(dolarizar,(list,tuple,set)):
             
-            #Chequeo de que se pudo cargar el tipo de cambio
-            if self.tc is None:
-                try :
-                    self.tc = BCRA(cargar_tc=True).tc_udh.copy(deep=True)
-                except:
-                    raise Exception('No se pudo cargar el Tipo de Cambio según la comunicación 3500 A del BRCRA.')
-            
             #Chequeo de columnas
             for col in dolarizar:
                 if not isinstance(col,str):
@@ -163,15 +156,21 @@ class DTE(ReporteBase,BCRA):
                 if col not in self.datos.columns:
                     raise ValueError(f'No se encontró la columna {col} entre {self.datos.columns.to_list()}')
   
-            self.datos = (self.datos
-                .merge(
-                    right=self.tc, 
-                    left_on='Fecha', 
-                    right_index=True, 
-                    how='left')
-                .assign(**{f'{c}_USD':lambda df_, c=c: df_[c].div(df_.TC) for c in dolarizar})
-                .rename(columns={c:f'{c}_ARS' for c in dolarizar})
-            )
+            #Chequeo de que se pudo cargar el tipo de cambio
+            self.tc = BCRA(cargar_tc=True).tc_udh.copy(deep=True)
+            if self.tc.empty:
+                print('No se pudo cargar el Tipo de Cambio según la comunicación 3500 A del BRCRA.')
+                self.tc = None
+            else:
+                self.datos = (self.datos
+                    .merge(
+                        right=self.tc, 
+                        left_on='Fecha', 
+                        right_index=True, 
+                        how='left')
+                    .assign(**{f'{c}_USD':lambda df_, c=c: df_[c].div(df_.TC) for c in dolarizar})
+                    .rename(columns={c:f'{c}_ARS' for c in dolarizar})
+                )
     
     def a_excel(self,descargar=False,filtro=None,exportar_consulta=False):
         
