@@ -1,4 +1,6 @@
+import bz2
 import json
+import pickle
 import requests
 import pandas as pd
 import dateutil as du
@@ -21,12 +23,14 @@ class DatosCdO():
         fecha_f = None ,
         reporte_trackers = False,
         reporte_produccion = False,
+        reporte_strings = False,
         reporte_mensual = False,
         exportar=False,
         dir_salida=None):
         
         # Inicialización de parámetros varios
-        self.señales_archivo = Path(dirs.get_dc_cfg()).joinpath('Señales_API_CdO.xlsx')
+        self.señales_ruta =  Path(dirs.get_dc_cfg())
+        self.señales_archivo = 'Señales_API_CdO'
         self.usr = usr
         self.pwd = pwd
         self.apikey = apikey
@@ -37,6 +41,7 @@ class DatosCdO():
         self.tz = du.tz.gettz('America/Argentina/San_Luis')
         self.rpt_prd = None
         self.rpt_trk = None
+        self.rpt_str = None
         
         #Cargar segmentos, mediciones, señales, etc.
         self.segments = None
@@ -44,7 +49,7 @@ class DatosCdO():
         self.mlocs_seg = None
         self.src_trk = None
         self.src_prd = None
-        self.src_rm = None
+        self.src_str = None
         self.mediciones_disponibles()
 
         # Descargar reportes deseados
@@ -57,6 +62,9 @@ class DatosCdO():
         
         if reporte_trackers:
             self.descargar_datos_trackers()
+
+        if reporte_strings:
+            self.descargar_datos_strings()
         
         # Exportar reportes deseados
         if isinstance(exportar,bool):
@@ -192,14 +200,14 @@ class DatosCdO():
     def obtener_señales(self, df, flt=None, n=0):
         
         df = (df
-        .pipe(lambda df_, flt=flt: df_[flt] if isinstance(flt,pd.Series) else df_)
-        .pipe(lambda df_, n=n: df_.iloc[:n,:] if n > 0 else df_)
-        .copy(deep=True))
+            .pipe(lambda df_, flt=flt: df_[flt] if isinstance(flt,pd.Series) else df_)
+            .pipe(lambda df_, n=n: df_.iloc[:n,:] if n > 0 else df_)
+            .copy(deep=True))
         
         return (df
         .merge(
             right = pd.concat(
-                objs = [self.__get_srcs_per_mloc(row.Segment_ID,row.Mloc_ID) for _, row in df.iterrows()],
+                objs = [self.__get_srcs_per_mloc(row.Segment_ID, row.Mloc_ID) for _, row in df.iterrows()],
                 axis=0,
                 ignore_index=True),
             on=['Segment_ID','Mloc_ID'],
@@ -264,67 +272,73 @@ class DatosCdO():
                 .sort_values(by=['Segment_Apcode','Mloc_Name'],ascending=[0,1])
                 .copy(deep=True))
 
+    def listado_señales_strings(self):
+        return (self.mlocs_seg
+            [self.mlocs_seg.Mloc_Apcode.eq('StringCurrent') & 
+            self.mlocs_seg.Segment_Name.str.contains('String',case=False)]
+            .sort_values(by='Segment_Name')
+            .copy(deep=True))
+
     def mediciones_disponibles(self):
 
-        archivo = self.señales_archivo
+        #Configurar nombres de archivos
+        xlsx = self.señales_ruta.joinpath(self.señales_archivo + '.xlsx')
+        pkl = self.señales_ruta.joinpath(self.señales_archivo + '.pkl')
 
-        if not archivo.exists():
-            crear_mlocs_seg = True
-            crear_src_rm = True
-            leer_segments = True
-            leer_mlocs = True
-            leer_src_trk = True
-            leer_src_prd = True
+        #Intentar leer archivos, del más rápido al más lento
+        if pkl.exists():
+            dfs = pickle.load(bz2.BZ2File(pkl, 'rb'))
+        elif xlsx.exists():
+            dfs = pd.read_excel(xlsx, sheet_name=None)
         else:
-            dfs = pd.read_excel(archivo, sheet_name=None)
-            
-            crear_mlocs_seg = 'mlocs_seg' not in dfs.keys()
-            leer_segments = ('segments' not in dfs.keys()) or crear_mlocs_seg
-            leer_mlocs = ('mlocs' not in dfs.keys()) or crear_mlocs_seg
-            
-            crear_src_rm = 'src_rm' not in dfs.keys()
-            leer_src_trk = ('src_trk' not in dfs.keys()) or crear_src_rm
-            leer_src_prd = ('src_prd' not in dfs.keys()) or crear_src_rm
+            dfs = {}
+
+        # Crear flags True/False
+        crear_mlocs_seg = 'mlocs_seg' not in dfs.keys()
+        consultar_segments = 'segments' not in dfs.keys()
+        consultar_mlocs = 'mlocs' not in dfs.keys()
+        consultar_src_trk = 'src_trk' not in dfs.keys()
+        consultar_src_prd = 'src_prd' not in dfs.keys()
+        consultar_src_str = 'src_str' not in dfs.keys()
+
+        # Con los flags ya creados, comenzar a consultar/leer datos
+        self.segments = self.__get_segments() if consultar_segments else dfs['segments']
+        self.mlocs = self.__get_mlocs(self.segments) if consultar_mlocs else dfs['mlocs']
         
         if crear_mlocs_seg:
-            self.segments = self.__get_segments() if leer_segments else dfs['segments']
-            self.mlocs = self.__get_mlocs(self.segments) if leer_mlocs else dfs['mlocs']
             self.mlocs_seg = (self.segments
-                            .merge(right=self.mlocs, on='Segment_ID',how='right')
-                            .drop(columns=['Segment_ApcodeIDX','Mloc_Sscode'])
-                            .loc[:,[
-                                'Segment_Apcode', 'Segment_Name', 'Mloc_Apcode',  'Mloc_Name', 
-                                'Segment_ID', 'Mloc_ID']])
+                .merge(right=self.mlocs, on='Segment_ID',how='right')
+                .drop(columns=['Segment_ApcodeIDX','Mloc_Sscode'])
+                .loc[:,['Segment_Apcode', 'Segment_Name','Mloc_Apcode',
+                        'Mloc_Name','Segment_ID', 'Mloc_ID']])
         else:
-            self.segments = dfs['segments']
-            self.mlocs = dfs['mlocs']
             self.mlocs_seg = dfs['mlocs_seg']
 
-        if crear_src_rm:
-            señales_trk = self.listado_señales_trackers(self.mlocs_seg)
-            señales_prd = self.listado_señales_produccion(self.mlocs_seg)
-            
-            self.src_trk = self.obtener_señales(señales_trk) if leer_src_trk else dfs['src_trk']
-            self.src_prd = self.obtener_señales(señales_prd) if leer_src_prd else dfs['src_prd']
-            self.src_rm = (pd
-                .concat([self.src_trk,self.src_prd],axis=0)
-                .pipe(lambda df_: 
-                    df_
-                    [df_.Src_calcPeriod.eq('10m')]
-                    .reset_index(drop=True)))
-        else:
-            self.src_trk =  dfs['src_trk']
-            self.src_prd =  dfs['src_prd']
-            self.src_rm =  dfs['src_rm']
-        
-        if any([crear_mlocs_seg, crear_mlocs_seg, leer_segments, leer_mlocs, leer_src_trk, leer_src_prd]):
-            with pd.ExcelWriter(archivo) as w:
+        self.src_trk = self.obtener_señales(self.listado_señales_trackers()) if consultar_src_trk else dfs['src_trk']
+        self.src_prd = self.obtener_señales(self.listado_señales_produccion()) if consultar_src_prd else dfs['src_prd']
+        self.src_str = self.obtener_señales(self.listado_señales_strings()) if consultar_src_str else dfs['src_str']
+
+        #Exportar en caso de haber cambios
+        if any([crear_mlocs_seg, consultar_segments, consultar_mlocs, consultar_src_trk, consultar_src_prd, consultar_src_str]):
+            # Exportar a Excel
+            with pd.ExcelWriter(xlsx) as w:
                 self.segments.to_excel(w,'segments',index=False)
                 self.mlocs.to_excel(w, 'mlocs',index=False)
                 self.mlocs_seg.to_excel(w,'mlocs_seg',index=False) 
                 self.src_trk.to_excel(w,sheet_name='src_trk',index=False)
                 self.src_prd.to_excel(w,sheet_name='src_prd',index=False)
-                self.src_rm.to_excel(w,sheet_name='src_rm',index=False)
+                self.src_str.to_excel(w,sheet_name='src_str',index=False)
+                
+            # Exportar a pickle
+            data = {
+                'segments': self.segments,
+                'mlocs': self.mlocs,
+                'mlocs_seg': self.mlocs_seg,
+                'src_trk': self.src_trk,
+                'src_prd': self.src_prd,
+                'src_str': self.src_str,}
+
+            pickle.dump(data, bz2.BZ2File(pkl, 'w'))
 
     #
     # Comandos para crear reportes
@@ -345,6 +359,14 @@ class DatosCdO():
                 ruta=ruta,
                 nombre=self.__exportar_configurar_archivo(encabezado='RawData Trackers',ruta=ruta,nombre=nombre))
 
+    def descargar_datos_strings(self,exportar=False,ruta=None,nombre=None):
+        self.rpt_str = self.obtener_mediciones(self.src_str.query('Src_calcPeriod == "10m"')).astype('Float32')
+        if exportar:
+            self.exportar(
+                reportes='strings',
+                ruta=ruta,
+                nombre=self.__exportar_configurar_archivo(encabezado='RawData Strings',ruta=ruta,nombre=nombre))
+
     #
     # Conjunto de funciones destinadas a exportar datos 
     # 
@@ -373,7 +395,7 @@ class DatosCdO():
     
     def __exportar_check_texto_reportes(self,reporte):
        
-        valores_posibles = ['todos','trackers','produccion',]
+        valores_posibles = ['todos','trackers','produccion','strings']
         
         # Chequear que
         if isinstance(reporte,str):
@@ -401,7 +423,7 @@ class DatosCdO():
         # Convierte a lista la variable, incluso si la entrada fue un string, queda como ['todos'] (por ejemplo)
         reportes = self.__exportar_check_reportes_seleccionados(reportes)
         
-        
+        # Preparar ruta y nombre de archivo para la exportación
         if len(reportes) == 1:
             if reportes[0] == 'todos':
                 archivo = self.__exportar_configurar_archivo(encabezado = 'Reportes blctools',ruta=ruta,nombre=nombre)
@@ -410,20 +432,22 @@ class DatosCdO():
         else:
             archivo = self.__exportar_configurar_archivo(encabezado = 'Reportes blctools',ruta=ruta,nombre=nombre)
         
-        
         # Chequeo de que las palabras claves se encuentre contenidas en la lista 'Reportes'
         todos = 'todos' in reportes
         produccion = todos or ('produccion' in reportes)
         trackers = todos or ('trackers' in reportes)
+        strings = todos or ('strings' in reportes)
         
         # Flags para chequear que cada uno de los reportes tiene datos efectivamente
         # Si alguno está sin datos, simplemente se lo va a saltear
         tiene_datos_produccion = self.rpt_prd is not None
         tiene_datos_trackers = self.rpt_trk is not None
+        tiene_datos_strings = self.rpt_str is not None
         
         # Flags que se utilizan al momento de decidir si un reporte se exporta a excel o no.
         exp_rpt_produccion =  produccion and tiene_datos_produccion
         exp_rpt_trackers = trackers and tiene_datos_trackers
+        exp_rpt_strings = strings and tiene_datos_strings
         
         # Hay casos donde puede haber dataframes vacíos
         # Segunda iteración sobre dichas flags
@@ -435,22 +459,27 @@ class DatosCdO():
             if exp_rpt_trackers: exp_rpt_trackers = not self.rpt_trk.empty
         except:
             pass
-            
-        # Preparar ruta y nombre de archivo para la exportación
-        
+        try:
+            if exp_rpt_strings: exp_rpt_strings = not self.rpt_str.empty
+        except:
+            pass
         
         # Rutina de exportación
         with pd.ExcelWriter(archivo) as w:
             if exp_rpt_produccion: 
-                self.rpt_prd.to_excel(
-                    w,
+                self.rpt_prd.to_excel(w,
                     sheet_name='rpt_prd',
                     freeze_panes=(1,1),
                     inf_rep='')
                 
             if exp_rpt_trackers: 
-                self.rpt_trk.to_excel(
-                    w,
+                self.rpt_trk.to_excel( w,
                     sheet_name='rpt_trk',
                     freeze_panes=(1,1),
+                    inf_rep='')
+                
+            if exp_rpt_strings: 
+                self.rpt_str.to_excel(w,
+                    sheet_name='rpt_str',
+                    freeze_panes=(1,1),
                     inf_rep='')
\ No newline at end of file
