@@ -344,46 +344,32 @@ class ReporteBase(ApiCammesa):
         
         return lista_sql
 
-    def _procesar_archivo(self,archivo):
+    def __procesar_archivo(self,archivo):
         
         print(f'Cargando .mdb en la memoria: {archivo}')
    
         #Preparar consultas SQL
         if self.parques:
-            lista_sql = self.__get_lista_sql()
-
-            SQL_datos = f'SELECT * FROM {self.tabla_datos} WHERE {self.col_filtro} IN {lista_sql};'
+            SQL_datos = f'SELECT * FROM {self.tabla_datos} WHERE {self.col_filtro} IN {self.__get_lista_sql()};'
         else:
             SQL_datos = f'SELECT * FROM {self.tabla_datos};'
             
-        SQL_fecha = f'SELECT * FROM {self.tabla_fecha};'
-
         #Preparando conexión con el archivo .mdb
         driver = '{Microsoft Access Driver (*.mdb, *.accdb)}'
-        str_conexion = f"Driver={driver};DBQ={str(archivo)};"
 
-        conexion = pyodbc.connect(str_conexion)
-        cursor = conexion.cursor()
+        with pyodbc.connect(f"Driver={driver};DBQ={archivo};") as conexion:
+            with conexion.cursor() as c:
+                return (pd
+                    .DataFrame(
+                        data = [tuple(r) for r in c.execute(SQL_datos).fetchall()],
+                        columns = [x[0] for x in c.description]
+                    )
+                    .assign(Fecha = c.execute(f'SELECT * FROM {self.tabla_fecha};').fetchall()[0][0])
+                    .pipe(lambda adf: adf.loc[:,['Fecha'] + adf.iloc[:,0:-1].columns.to_list()])
+                )
 
-        #Recuperar datos desde el archivo
-        data_archivo = cursor.execute(SQL_datos).fetchall()
-        encabezado = ['Fecha',] + [x[0] for x in cursor.description]
 
-        fecha_archivo = cursor.execute(SQL_fecha).fetchall()
-
-        #Colocarle fecha a los registros
-        for index,_ in enumerate(data_archivo):
-            data_archivo[index] = (fecha_archivo[0][0],) + tuple(data_archivo[index])
-
-        #Cerrar conexión con el archivo
-        cursor.close()
-        conexion.close()
-        df = pd.DataFrame(data_archivo,columns=encabezado)
-        df['Fecha'] = pd.to_datetime(df['Fecha'], format='%d/%m/%Y')
-        
-        return df
-
-    def _procesar_archivos(self):
+    def __procesar_archivos(self):
         '''Abre y filtra todos los archivos disponibles MDB para los parques seleccionados.
         Devuelve un df de pandas unificado.
         '''
@@ -394,7 +380,7 @@ class ReporteBase(ApiCammesa):
             print(f"Iniciando procesamiento de {cant_archivos} archivos")
             print(f'Ruta de carga: {self.archivos_disponibles[0].parent}')
             # Lista de Dataframes
-            dataframes = [self._procesar_archivo(archivo) for archivo in self.archivos_disponibles]
+            dataframes = [self.__procesar_archivo(archivo) for archivo in self.archivos_disponibles]
             df = pd.concat(dataframes)
             
             if df.empty:
@@ -450,7 +436,7 @@ class ReporteBase(ApiCammesa):
 
         #Hay que encontrar los archivos acá
         if self.archivos_disponibles:
-            self._datos = self._procesar_archivos()
+            self._datos = self.__procesar_archivos()
         else:
             raise Exception(f'No hay archivos disponibles para cargar entre las fechas {self.fecha_i} y {self.fecha_f}')
         
