@@ -21,6 +21,19 @@ __formatos_default_periodo = [
     '%d.%m.%Y','%d%m%y',
     '%d%m%Y','%y-%m-%d',] 
 
+
+def convertir_año_a_fecha(f,fin_de_año=True):
+    
+    try:
+        f = int(f)
+    except:
+        return f
+    
+    if fin_de_año:
+        return __dt.datetime(year=int(f),month=12,day=31)
+    else:
+        return __dt.datetime(year=int(f),month=1,day=1)
+
 def hora_op(fecha,prevenir_futuro=False):
     fecha = validar_fecha(fecha,prevenir_futuro=prevenir_futuro)
     if fecha.minute == 0:
@@ -92,7 +105,7 @@ def mes_dia_1(fecha,formatos=__formatos_default_fecha,prevenir_futuro=True):
 
 def mes_ult_dia(fecha,formatos=__formatos_default_fecha,prevenir_futuro=True):
     fecha = validar_fecha(fecha,formatos=formatos,prevenir_futuro=prevenir_futuro)
-    fecha = sumar_mes(mes_dia_1(fecha)) - __dt.timedelta(days=1)
+    fecha = sumar_mes(mes_dia_1(fecha,prevenir_futuro=prevenir_futuro),prevenir_futuro=prevenir_futuro) - __dt.timedelta(days=1)
     return fecha
 
 def mes_periodo(fecha,formatos=__formatos_default_periodo,prevenir_futuro=True):
@@ -223,6 +236,22 @@ def iterar_mensual(ts_ini,ts_fin,formatos=__formatos_default_fecha,prevenir_futu
         
         ts_loop = sumar_mes(ts_loop)
 
+def lista_mensual(fecha,n,ult_dia = True):
+
+
+    if ult_dia:
+        
+        func = lambda x: mes_ult_dia(x,prevenir_futuro=False) 
+    else:
+        func = lambda x: mes_dia_1(x,prevenir_futuro=False)
+        
+    fechas = [func(fecha),]
+
+    for _ in range(n):
+        fechas.append(func(sumar_mes(fechas[-1])))
+
+    return fechas
+
 def _procesar_formatos(fecha,formatos):
     for formato in formatos:
         try:
